[tor-commits] [goptlib/master] Return a generic net.Conn from ConnectOr.

dcf at torproject.org dcf at torproject.org
Mon Dec 9 02:49:51 UTC 2013


commit ee5deba3d72bbde1cfd42547066519321be88bff
Author: David Fifield <david at bamsoftware.com>
Date:   Sun Dec 8 11:21:13 2013 -0800

    Return a generic net.Conn from ConnectOr.
---
 pt.go |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt.go b/pt.go
index b8b88ce..f926ee9 100644
--- a/pt.go
+++ b/pt.go
@@ -743,10 +743,10 @@ func extOrPortSetup(s io.ReadWriter, addr net.Addr, methodName string) error {
 }
 
 // Connect to info.ExtendedOrAddr if defined, or else info.OrAddr, and return an
 // open *net.TCPConn. If connecting to the extended OR port, extended OR port
 // authentication à la 217-ext-orport-auth.txt is done before returning; an
 // error is returned if authentication fails.
-func ConnectOr(info *ServerInfo, addr net.Addr, methodName string) (*net.TCPConn, error) {
+func ConnectOr(info *ServerInfo, addr net.Addr, methodName string) (net.Conn, error) {
 	if info.ExtendedOrAddr == nil {
 		return net.DialTCP("tcp", nil, info.OrAddr)
 	}
@@ -743,10 +743,10 @@ func extOrPortSetup(s io.ReadWriter, addr net.Addr, methodName string) error {
 
 // Connect to info.ExtendedOrAddr if defined, or else info.OrAddr, and return an
-// open *net.TCPConn. If connecting to the extended OR port, extended OR port
+// open net.Conn. If connecting to the extended OR port, extended OR port
 // authentication à la 217-ext-orport-auth.txt is done before returning; an
 // error is returned if authentication fails.





More information about the tor-commits mailing list